@@ -4,7 +4,7 @@
 #'
 #' @param data A data set in wide format including an ID variable and variables for each measurement point.
 #' @param sg_crit1_cutoff Numeric, specifying the cut-off value to be used for the first sudden gains criterion.
-#' The function \code{\link{define_crit1_cutoff}} can be used to calcualate a cutoff value based on the Reliable Change Index (RCI; Jacobson & Truax, 1991).
+#' The function \code{\link{define_crit1_cutoff}} can be used to calculate a cutoff value based on the Reliable Change Index (RCI; Jacobson & Truax, 1991).
 #' If set to \code{NULL} the first criterion wont be applied.
 #' @param sg_crit2_pct Numeric, specifying the percentage change to be used for the second sudden gains/losses criterion.
 #' If set to \code{NULL} the second criterion wont be applied.
@@ -17,7 +17,8 @@
 #' A critical value of 2.776 is used when all three data points before and after a potential gain are available,
 #' where one datapoint is missing either before or after a potential gain a critical value of 3.182 is used,
 #' and where one datapoint is missing both before and after the gain a critical value of 4.303 is used (for sg_crit3_alpha = 0.05).
-#' If set to \code{FALSE} a critical value of 2.776 will instead be used for all comparisons, regardless of missingnes in the sequence of data points that are investigated for potential sudden gains.
+#' If set to \code{FALSE} the critical value set in \code{sg_crit3_critical_value} will instead be used for all comparisons, regardless of missingnes in the sequence of data points that are investigated for potential sudden gains.
+#' @param sg_crit3_critical_value Numeric, specifying the critical value to instead be used for all comparisons, regardless of missingnes in the sequence of data points that are investigated for potential sudden gains.#'
 #' @param id_var_name String, specifying the name of the ID variable. Each row should have a unique value.
 #' @param sg_var_list Vector, specifying the variable names of each measurement point sequentially.
 #' @param tx_start_var_name String, specifying the variable name of the first measurement point of the intervention.
@@ -61,8 +62,9 @@
 #'                path = temp)
 
 write_byperson <- function(data, sg_crit1_cutoff, id_var_name, sg_var_list, tx_start_var_name, tx_end_var_name, sg_measure_name,
-                           sg_crit2_pct = .25, sg_crit3 = TRUE, sg_crit3_alpha = .05, sg_crit3_adjust = TRUE, identify = c("sg", "sl"), identify_sg_1to2 = FALSE,
-                           multiple_sg_select = c("first", "last", "smalles", "largest"), data_is_bysg = FALSE,
+                           sg_crit2_pct = .25, sg_crit3 = TRUE, sg_crit3_alpha = .05, sg_crit3_adjust = TRUE, sg_crit3_critical_value = 2.776,
+                           identify = c("sg", "sl"), identify_sg_1to2 = FALSE,
+                           multiple_sg_select = c("first", "last", "smallest", "largest"), data_is_bysg = FALSE,
                            format = c("CSV", "SPSS", "STATA", "Excel"), path, stata_version = 14, ...) {
 
     # Check arguments
@@ -77,6 +79,7 @@ write_byperson <- function(data, sg_crit1_cutoff, id_var_name, sg_var_list, tx_s
                                      sg_crit3 = sg_crit3,
                                      sg_crit3_alpha = sg_crit3_alpha,
                                      sg_crit3_adjust = sg_crit3_adjust,
+                                     sg_crit3_critical_value = sg_crit3_critical_value,
                                      id_var_name = id_var_name,
                                      tx_start_var_name = tx_start_var_name,
                                      tx_end_var_name = tx_end_var_name,
